import fs from "node:fs";
import { Mode } from "@canvas-js/okra";
import { Tree as PersistentTree } from "@canvas-js/okra-lmdb";
import { Tree as MemoryTree } from "@canvas-js/okra-memory";
import { ModelDB } from "@canvas-js/modeldb-sqlite";
import { AbstractGossipLog } from "../AbstractGossipLog.js";
export class GossipLog extends AbstractGossipLog {
    constructor({ directory = null, ...init }) {
        super(init);
        Object.defineProperty(this, "db", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "tree", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        if (directory === null) {
            this.tree = new MemoryTree({ mode: Mode.Index });
            this.db = new ModelDB({
                path: null,
                models: { ...init.schema, ...AbstractGossipLog.schema },
            });
        }
        else {
            if (!fs.existsSync(directory)) {
                fs.mkdirSync(directory, { recursive: true });
            }
            const tree = new PersistentTree(`${directory}/message-index`, {
                mode: Mode.Index,
                mapSize: 0xffffffff,
            });
            this.tree = tree;
            this.db = new ModelDB({
                path: `${directory}/db.sqlite`,
                models: { ...init.schema, ...AbstractGossipLog.schema },
            });
        }
    }
    async rebuildMerkleIndex() {
        if (this.tree instanceof MemoryTree) {
            // ...
        }
    }
}
